@@ -10,33 +10,37 @@ from fastutils import rsautils
 
 
 class AbstractResultPacker(object):
-    
-    def pack_result(self, result, **kwargs):
+    """第1个位置参数加入了后缀，避免与kwargs中的参数冲突。
+    """
+    def pack_result(self, __result_Pu1dvy86uRLpdNu2Czyf, **kwargs):
         raise NotImplementedError()
 
-    def pack_error(self, error, **kwargs):
+    def pack_error(self, __error_Pu1dvy86uRLpdNu2Czyf, **kwargs):
         raise NotImplementedError()
 
-    def unpack(self, data, **kwargs):
+    def unpack(self, __data_Pu1dvy86uRLpdNu2Czyf, **kwargs):
         raise NotImplementedError()
 
 
 
 class SimpleJsonResultPacker(AbstractResultPacker):
 
-    def pack_result(self, result, **kwargs):
+    def pack_result(self, __result_Pu1dvy86uRLpdNu2Czyf, **kwargs):
+        result = __result_Pu1dvy86uRLpdNu2Czyf
         return {
             "success": True,
             "result": result,
         }
 
-    def pack_error(self, error, **kwargs):
+    def pack_error(self, __error_Pu1dvy86uRLpdNu2Czyf, **kwargs):
+        error = __error_Pu1dvy86uRLpdNu2Czyf
         return {
             "success": False,
             "error": error,
         }
 
-    def unpack(self, data, **kwargs):
+    def unpack(self, __data_Pu1dvy86uRLpdNu2Czyf, **kwargs):
+        data = __data_Pu1dvy86uRLpdNu2Czyf
         if not data:
             raise bizerror.BadResponseContent(content=data)
         if isinstance(data, (str, bytes)):
@@ -63,15 +67,18 @@ class SafeJsonResultPacker(SimpleJsonResultPacker):
         self.result_encoder = result_encoder
         self.client_id_fieldname = client_id_fieldname
 
-    def pack_result(self, result, **kwargs):
+    def pack_result(self, __result_Pu1dvy86uRLpdNu2Czyf, **kwargs):
+        result = __result_Pu1dvy86uRLpdNu2Czyf
         result = super().pack_result(result, **kwargs)
         return self.encrypt_data(result, **kwargs)
 
-    def pack_error(self, error, **kwargs):
+    def pack_error(self, __error_Pu1dvy86uRLpdNu2Czyf, **kwargs):
+        error = __error_Pu1dvy86uRLpdNu2Czyf
         error =  super().pack_error(error, **kwargs)
-        return self.encrypt_data(error, **kwargs)
+        return self.encrypt_data(__error_Pu1dvy86uRLpdNu2Czyf, **kwargs)
 
-    def encrypt_data(self, data, **kwargs):
+    def encrypt_data(self, __data_Pu1dvy86uRLpdNu2Czyf, **kwargs):
+        data = __data_Pu1dvy86uRLpdNu2Czyf
         # get client rsa publickey
         get_client_rsa_publickey = kwargs["get_client_rsa_publickey"]
         client_id = kwargs[self.client_id_fieldname]
@@ -87,7 +94,8 @@ class SafeJsonResultPacker(SimpleJsonResultPacker):
             self.encrypted_data_fieldname: result_data,
         }
  
-    def unpack(self, data, **kwargs):
+    def unpack(self, __data_Pu1dvy86uRLpdNu2Czyf, **kwargs):
+        data = __data_Pu1dvy86uRLpdNu2Czyf
         if not data:
             raise bizerror.BadResponseContent(content=data)
         if isinstance(data, (str, bytes)):
