@@ -125,12 +125,12 @@ apiview = Apiview(simple_result_packer)
 class requires(ApiviewDecorator):
     """Make sure the parameters are given.
     """
-    def __init__(self, *parameter_names):
-        self.parameter_names = parameter_names
+    def __init__(self, *required_parameter_names):
+        self.required_parameter_names = required_parameter_names
 
     def main(self, _django_apiview_request, func):
         missing_names = []
-        for name in self.parameter_names:
+        for name in self.required_parameter_names:
             if isinstance(name, str):
                 if not name in _django_apiview_request.data:
                     missing_names.append(name)
